# -*- coding: utf-8 -*-
from zope.interface import Attribute
from zope.interface import Interface


class IMessage(Interface):
    """A single status message."""

    message = Attribute('The text of this message. Usally a Message object.')

    type = Attribute('The type of this message.')


class IStatusMessage(Interface):
    """An adapter for the BrowserRequest to handle status messages."""

    def addStatusMessage(text, type=u'info'):
        """Add a status message."""

    def add(text, type=u'info'):
        """Add a status message."""

    def showStatusMessages():
        """Removes all status messages and returns them for display.
        """
    def show():
        """Removes all status messages and returns them for display.
        """



# -*- coding: utf-8 -*-
from doctest import DocTestSuite
from unittest import TestSuite


test_list = (
    DocTestSuite('Products.statusmessages.adapter'),
    DocTestSuite('Products.statusmessages.message'),
)


def test_suite():
    return TestSuite(test_list)



# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup


version = '5.0.4'

setup(
    name='Products.statusmessages',
    version=version,
    description='statusmessages provides an easy way of handling '
                'internationalized status messages managed via an '
                'BrowserRequest adapter storing status messages in '
                'client-side cookies.',
    long_description=(open('README.rst').read() + '\n' +
                      open('CHANGES.rst').read()),
    classifiers=[
        'Framework :: Plone',
        'Framework :: Plone :: 5.0',
        'Framework :: Plone :: 5.1',
        'Framework :: Zope2',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='Zope CMF Plone status messages i18n',
    author='Hanno Schlichting',
    author_email='plone-developers@lists.sourceforge.net',
    url='https://pypi.python.org/pypi/Products.statusmessages',
    license='BSD',
    packages=find_packages(exclude=['ez_setup']),
    namespace_packages=['Products'],
    include_package_data=True,
    zip_safe=False,
    extras_require=dict(
        test=[
            'zope.component',
            'Zope2',
        ],
    ),
    install_requires=[
        'setuptools',
        'six',
        'zope.annotation',
        'zope.i18n',
        'zope.interface',
    ],
)



# -*- coding: UTF-8 -*-
from __future__ import unicode_literals

import unittest


class TestEncoding(unittest.TestCase):

    def test_encoding_msg_with_type(self):
        """Test message encoding:
        """
        from Products.statusmessages.message import Message
        from Products.statusmessages.message import decode
        m = Message('späm', 'eggs')
        self.assertEqual(
            m.encode(),
            b'\x00\xa4sp\xc3\xa4meggs',
        )
        self.assertEqual(decode(m.encode())[0], m)

    def test_encoding_msg_without_type(self):
        from Products.statusmessages.message import Message
        from Products.statusmessages.message import decode
        m = Message('späm')
        self.assertEqual(
            m,
            Message('späm'),
        )
        self.assertEqual(m.encode(), b'\x00\xa0sp\xc3\xa4m')
        self.assertEqual(decode(m.encode())[0], m)

    def test_decoding(self):
        """Test message decoding:
        """
        from Products.statusmessages.message import decode

        # Craft a wrong value:
        m, rem = decode(b'\x01\x84spameggs')
        self.assertEqual(
            m.message,
            'spameggs',
        )
        self.assertEqual(
            m.type,
            '',
        )
        self.assertEqual(rem, b'')

        # Craft another wrong value:
        m, rem = decode(b'\x00\x24spameggs')
        self.assertEqual(
            m.message,
            's',
        )
        self.assertEqual(
            m.type,
            'pame',
        )
        self.assertEqual(rem, b'ggs')

        # And another wrong value:
        m, rem = decode(b'\x00spameggs')
        self.assertEqual(
            m.message,
            'pam',
        )
        self.assertEqual(
            m.type,
            'eggs',
        )
        self.assertEqual(rem, b'')

        # And yet another wrong value:
        m, rem = decode('')

        self.assertIs(m, None)
        self.assertEqual(rem, b'')
